import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:one_target_mobile_sdk/one_target_mobile_sdk.dart';
import 'package:one_target_mobile_sdk_example/common/utils.dart';
import 'package:one_target_mobile_sdk_example/screens/tracking/advancedTracking/customer_screen.dart';

class DetailFlightScreen extends StatefulWidget {
  const DetailFlightScreen({Key? key}) : super(key: key);

  @override
  State<DetailFlightScreen> createState() => _DetailFlightScreenState();
}

class _DetailFlightScreenState extends State<DetailFlightScreen> {
  bool _isTracking = false;

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        backgroundColor: Colors.white,
        elevation: 0,
        leading: IconButton(
          icon: const Icon(Icons.arrow_back_ios, color: Colors.black),
          onPressed: () {
            Get.back();
          },
        ),
        actions: [
          Utils.getDebugViewIcon(),
        ],
        centerTitle: true,
        title: const Text(''),
      ),
      body: Container(
        padding: const EdgeInsets.all(16.0),
        child: Column(
          children: [
            Expanded(
              child: ListView(
                physics: const BouncingScrollPhysics(),
                children: [
                  const SizedBox(height: 16.0),
                  Align(
                    alignment: Alignment.center,
                    child: Utils.getText(
                      "Hồ Chí Minh - Hà Nội",
                      18,
                      FontWeight.w500,
                      Colors.black,
                    ),
                  ),
                  const SizedBox(height: 16.0),
                  const SizedBox(height: 16.0),
                  _buildDetailView("22:10", "00:10", "1,450,000đ"),
                  const SizedBox(height: 16.0),
                  _buildDetailView("10:10", "12:10", "1,000,000đ"),
                ],
              ),
            ),
            Utils.getButton(
              "Tiếp theo",
              16.0,
              Colors.white,
              _isTracking ? Colors.grey : Colors.deepPurple,
              null,
              () {
                _trackEvent();
              },
            ),
            const SizedBox(height: 16.0),
          ],
        ),
      ),
    );
  }

  Widget _buildDetailView(
    String timeSGN,
    String timeHAN,
    String money,
  ) {
    return Container(
      padding: const EdgeInsets.fromLTRB(16.0, 16.0, 16.0, 16.0),
      decoration: BoxDecoration(
        border: Border.all(
          width: 1.0,
          color: Colors.grey,
        ),
        borderRadius: const BorderRadius.all(Radius.circular(0)),
      ),
      child: Row(
        children: [
          Column(
            children: [
              Utils.getText(
                "SGN",
                16.0,
                FontWeight.w500,
                Colors.black,
              ),
              const SizedBox(height: 16.0),
              Utils.getText(
                timeSGN,
                14.0,
                FontWeight.w400,
                Colors.black,
              ),
            ],
          ),
          const SizedBox(width: 16.0),
          Column(
            children: [
              Utils.getText(
                "2 giờ 10 phút",
                14.0,
                FontWeight.w400,
                Colors.black,
              ),
              const SizedBox(height: 16.0),
              const SizedBox(height: 16.0),
              Utils.getText(
                "Bay thẳng",
                14.0,
                FontWeight.w400,
                Colors.black,
              ),
            ],
          ),
          const SizedBox(width: 16.0),
          Column(
            children: [
              Utils.getText(
                "HAN",
                16.0,
                FontWeight.w500,
                Colors.black,
              ),
              const SizedBox(height: 16.0),
              Utils.getText(
                timeHAN,
                14.0,
                FontWeight.w400,
                Colors.black,
              ),
            ],
          ),
          const SizedBox(width: 16.0),
          Container(
            height: 80.0,
            color: Colors.grey,
            width: 1.0,
          ),
          const SizedBox(width: 16.0),
          Expanded(
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.center,
              children: [
                Utils.getText(
                  "Giá từ",
                  14.0,
                  FontWeight.w400,
                  Colors.black,
                ),
                const SizedBox(height: 16.0),
                Utils.getText(
                  money,
                  14.0,
                  FontWeight.w400,
                  Colors.black,
                ),
              ],
            ),
          ),
        ],
      ),
    );
  }

  void _trackEvent() {
    if (_isTracking) {
      return;
    }
    setState(() {
      _isTracking = true;
    });
    var profile = <Map>[];
    G1SDK.instance.trackEvent(
      {},
      profile,
      "add_to_cart",
      {
        "ecommerce.currency": "VND",
        "ecommerce.trip_from": "HAN",
        "ecommerce.trip_to": "SGN",
        "ecommerce.trip_start_date": "2022-09-23",
        "ecommerce.trip_return_date": "2022-09-23",
        "ecommerce.trip_passengers": "1",
        "ecommerce.trip_passengers_adult": "2",
        "ecommerce.trip_passengers_children": "1",
        "ecommerce.trip_passengers_infant": "0",
        "ecommerce.trip_type": "roundTrip",
        "ecommerce.items.0.item_id": "VJ197",
        "ecommerce.items.0.item_name": "Flight:HAN:SGN",
        "ecommerce.items.0.item_category": "FareOption",
        "ecommerce.items.0.item_variant": "Eco",
        "ecommerce.items.0.item_list_id": "Outbound:HAN:SGN",
        "ecommerce.items.0.index": "1",
        "ecommerce.items.0.quantity": "1",
        "ecommerce.items.0.price": "39.000đ",
        "ecommerce.items.0.flight_time": "06:20-08:30",
        "ecommerce.items.0.flight_from": "HAN",
        "ecommerce.items.0.flight_to": "SGN",
        "ecommerce.items.0.flight_date": "2022-09-23",
        "ecommerce.trip_route": "SGN-HN",
      },
      onResponse: (value) async {
        Utils.log(">>>onResponse $value");
        await Future.delayed(const Duration(milliseconds: 700));
        Get.to(() => const CustomerScreen());
        setState(() {
          _isTracking = false;
        });
      },
      onFailure: (value) {
        Utils.log(">>>onFailure $value");
        setState(() {
          _isTracking = false;
        });
      },
    );
  }
}
