import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:one_target_mobile_sdk/one_target_mobile_sdk.dart';
import 'package:one_target_mobile_sdk_example/common/utils.dart';

class SimpleTrackingScreen extends StatefulWidget {
  const SimpleTrackingScreen({Key? key}) : super(key: key);

  @override
  State<SimpleTrackingScreen> createState() => _SimpleTrackingScreenState();
}

class _SimpleTrackingScreenState extends State<SimpleTrackingScreen> {
  Object? _response;

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        leading: IconButton(
          icon: const Icon(Icons.arrow_back_ios, color: Colors.white),
          onPressed: () {
            Get.back();
          },
        ),
        actions: [
          Utils.getDebugViewIcon(),
        ],
        centerTitle: true,
        title: const Text('SimpleTrackingScreen'),
      ),
      body: Container(
        padding: const EdgeInsets.all(16.0),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            FutureBuilder<String?>(
              future: G1SDK.instance.platformVersion,
              builder: (_, snapshot) {
                return Text(snapshot.data ?? '');
              },
            ),
            SampleButton(
              text: "Send event 1",
              onPressed: () {
                _trackEvent1();
              },
            ),
            SampleButton(
              text: "Send event 2",
              onPressed: () {
                _trackEvent2();
              },
            ),
            const SizedBox(height: 32.0),
            const Text('>>>RESPONSE'),
            const SizedBox(height: 16.0),
            if (_response != null)
              Expanded(
                child: ListView(
                  children: [
                    Text(Utils.getPrettyString(_response)),
                  ],
                ),
              ),
          ],
        ),
      ),
    );
  }

  void _trackEvent1() {
    _displayResponse(null);
    var profile = <Map>[];
    profile.add({
      "name": "Loitp Flutter",
      "email": "Loi123@galaxy.one",
    });
    G1SDK.instance.trackEvent(
      {
        "phone": "0766040293",
        "email": "Loi123@galaxy.one",
      },
      profile,
      "event_name",
      {
        "pageTitle": "Passenger Information from Flutter",
        "pagePath": "/home",
      },
      onResponse: (value) {
        Utils.log(">>>onResponse $value");
        _displayResponse(value);
      },
      onFailure: (value) {
        Utils.log(">>>onFailure $value");
        _displayResponse(value);
      },
    );
  }

  void _trackEvent2() {
    _displayResponse(null);
    var profile = <Map>[];
    profile.add({
      "name": "Loi222 Flutter",
      "email": "Loi222@galaxy.one",
    });
    profile.add({
      "name": "Loi333 Flutter",
      "email": "Loi333@galaxy.one",
    });
    profile.add({
      "name": "Loi444 Flutter",
      "email": "Loi444@galaxy.one",
    });
    G1SDK.instance.trackEvent(
      {
        "phone": "0766040293",
        "email": "loitp@galaxy.one",
      },
      profile,
      "track_now_event",
      {
        "name": "Loitp Flutter",
        "bod": "01/01/2000",
        "player_id": 123456,
      },
      onResponse: (value) {
        Utils.log(">>>onResponse $value");
        _displayResponse(value);
      },
      onFailure: (value) {
        Utils.log(">>>onFailure $value");
        _displayResponse(value);
      },
    );
  }

  void _displayResponse(Object? response) {
    setState(() {
      _response = response;
    });
  }
}
