import 'dart:async';

import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

import 'common/const.dart';

class G1SDK {
  G1SDK._() {
    _channel.setMethodCallHandler(_streamLog);
  }

  static G1SDK? _instance;

  static get instance => _instance ??= G1SDK._();

  static const envDev = 1;
  static const envStag = 2;
  static const envProd = 3;
  static const MethodChannel _channel = MethodChannel(Const.sdk);
  Function(String msg)? onLog;

  // void addOnLogUpdated(Function(String msg)? onLog) {
  //   this.onLog = onLog;
  // }

  void _log(String msg) {
    if (kDebugMode) {
      print(msg);
    }
  }

  Future<String?> get platformVersion async {
    final String? version =
        await _channel.invokeMethod(Const.getPlatformVersion);
    return version;
  }

  Future<bool> setupSDK(
    int env,
    String? writeKey,
    String? oneTargetAppPushID, {
    bool isShowLog = false,
    bool isEnableIAM = true,
    Function(String msg)? onLog,
    int? maxNumberApiPolling,
  }) async {
    if (env != envDev && env != envStag && env != envProd) {
      return false;
    }
    this.onLog = onLog;
    return await _channel.invokeMethod(
          Const.setupTracking,
          {
            "env": env,
            "writeKey": writeKey,
            "oneTargetAppPushID": oneTargetAppPushID,
            "isShowLog": isShowLog,
            "isEnableIAM": isEnableIAM,
            "maxNumberApiPolling": maxNumberApiPolling,
          },
        ) ==
        true;
  }

  void trackEvent(
      Map? identityId, List<Map>? profile, String? eventName, Map? eventData,
      {Function(Object?)? onResponse, Function(Object?)? onFailure}) async {
    // print("identityId $identityId");
    // print("profile profile");
    // print("eventName $eventName");
    // print("eventData $eventData");
    final result = await _channel.invokeMethod<Map<dynamic, dynamic>>(
      Const.trackEvent,
      {
        "identityId": identityId,
        "profile": profile,
        "eventName": eventName,
        "eventData": eventData,
      },
    );
    if (result != null) {
      final input = result['input'] as Object?;
      // _log("~~~~~~~~~~~~~monitorEvent: ${jsonEncode(monitorEvent)}");
      final isSuccessful = result['isSuccessful'] as bool?;
      final code = result['code'] as int?;
      final response = result['response'] as Object?;
      // _log("~~~~~~~~~~~~~isSuccessful: $isSuccessful");
      // _log("~~~~~~~~~~~~~code: $code");
      // _log("~~~~~~~~~~~~~response: ${jsonEncode(response)}");

      // if (kDebugMode) {
      //   await Future.delayed(const Duration(seconds: 2));
      // }

      if (response != null) {
        onResponse?.call({
          if (input != null) "input": input,
          if (isSuccessful != null) "isSuccessful": isSuccessful,
          if (code != null) "code": code,
          "response": response,
        });
      }
      final error = result['error'] as String?;
      if (error != null) {
        onFailure?.call({
          if (input != null) "input": input,
          "error": error,
        });
      }
    }
  }

  Future<void> _streamLog(MethodCall call) async {
    if (call.method == Const.logBack) {
      // _log('_streamLog: ${call.arguments}');
      onLog?.call(call.arguments);
    }
  }
}
